aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/editgroup_edits.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/editgroup_edits.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/editgroup_edits.py17
1 files changed, 8 insertions, 9 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/editgroup_edits.py b/python_openapi_client/fatcat_openapi_client/models/editgroup_edits.py
index 6a8e2a46..39340ce9 100644
--- a/python_openapi_client/fatcat_openapi_client/models/editgroup_edits.py
+++ b/python_openapi_client/fatcat_openapi_client/models/editgroup_edits.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -16,23 +16,22 @@ import re # noqa: F401
import six
-from fatcat_openapi_client.models.entity_edit import EntityEdit # noqa: F401,E501
-
class EditgroupEdits(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'containers': 'list[EntityEdit]',
'creators': 'list[EntityEdit]',
'files': 'list[EntityEdit]',
@@ -53,7 +52,7 @@ class EditgroupEdits(object):
}
def __init__(self, containers=None, creators=None, files=None, filesets=None, webcaptures=None, releases=None, works=None): # noqa: E501
- """EditgroupEdits - a model defined in Swagger""" # noqa: E501
+ """EditgroupEdits - a model defined in OpenAPI""" # noqa: E501
self._containers = None
self._creators = None
@@ -230,7 +229,7 @@ class EditgroupEdits(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -16,23 +16,22 @@ import re # noqa: F401
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name